@@ -6,15 +6,15 @@ test_that("Functional mean", {
     model(fm = FMEAN(Mortality))
   fc <- forecast(fm)
   expect_no_error(autoplot(fc))
-  expect_equal(dim(fm), c(3L, 3L))
-  expect_equal(dim(tidy(fm)), c(300L,9L))
-  expect_equal(colnames(glance(fm)), c("Sex", "Code", ".model", "sigma2"))
+  expect_equal(dim(fm), c(3L, 4L))
+  expect_equal(dim(tidy(fm)), c(303L,10L))
+  expect_equal(colnames(glance(fm)), c("Sex", "State", "Code", ".model", "sigma2"))
   expect_equal(mean(augment(fm)$.resid, na.rm=TRUE), 0)
   expect_no_error(residuals(fm, type = "innov"))
   expect_no_error(residuals(fm, type = "response"))
   expect_no_error(fitted(fm))
-  expect_equal(NROW(generate(fm, times = 2)), 1200L)
-  expect_equal(NROW(fc), 600)
+  expect_equal(NROW(generate(fm, times = 2)), 1212L)
+  expect_equal(NROW(fc), 606)
   expect_equal(fc |>
     dplyr::filter(Sex == "female", Age == 0, Year == 2021) |>
       dplyr::pull(.mean), 0.02701234, tolerance = 1e-7)
